==============================
MMU - Model Metric Uncertainty
==============================

**A library for the evaluation of model performance and estimation of the uncertainty on these metrics.**

.. image:: figs/pr_curve_mult_w_points.png
  :width: 1000
  :alt: Uncertainty on the Precision-Recall curve

.. only:: latex

.. include:: readme.rst
   :start-line: 34

**Contents**

.. only:: not latex

.. toctree::
    :caption: MMU
    :maxdepth: 2
    
    introduction
    installation
    basics
    changelog

.. toctree::
    :caption: API
    :maxdepth: 3

    metrics
    estimators

.. toctree::
    :caption: Advanced
    :maxdepth: 2

    contributing
    extension
